`IndustryGuesser` is meant to guess the industry of the company based on its name.

## Installation

```bash
tar -xvf IndustryGuesser*.tar.gz
cd IndustryGuesser*/
python setup.py install
```

## API usage.
```bash
from industryguesser import guess_industry, guess_industries

>>> guess_industries(['Micron', 'Dell', 'Anthony Law Corporation', 'X0PA Ai', 'McKinsey & Company', 'alibaba'])
['Semiconductors', 'Information Technology and Services', 'Law Practice', None, 'Management Consulting', 'Internet']

>>> predict_genders(['Micron'], return_prob=True)
[{'industry': 'Semiconductors',
  'prob': [{'Accounting': 8.2165e-05},
   {'Airlines/Aviation': 0.00017043948},
   {'Alternative Dispute Resolution': 0.0},
   {'Alternative Medicine': 2.6166439e-05},
   {'Animation': 1.4901161e-07},
   {'Apparel & Fashion': 1.9013882e-05},
   {'Architecture & Planning': 8.34465e-06},
   {'Arts and Crafts': 3.4570694e-06},
   {'Automotive': 1.8298626e-05},
   {'Aviation & Aerospace': 0.0076958835},
   {'Banking': 1.4901161e-07},
   {'Biotechnology': 0.14243287},
   {'Broadcast Media': 1.2904406e-05},
   {'Building Materials': 0.00012370944},
   {'Business Supplies and Equipment': 0.00056251884},
   {'Capital Markets': 1.4901161e-07},
   {'Chemicals': 0.0004875958},
   {'Civic & Social Organization': 7.748604e-07},
   {'Civil Engineering': 1.7225742e-05},
   {'Commercial Real Estate': 5.9604645e-08},
   {'Computer & Network Security': 3.4093857e-05},
   {'Computer Games': 4.9859285e-05},
   {'Computer Hardware': 0.00012207031},
   {'Computer Networking': 2.8938055e-05},
   {'Computer Software': 0.0013174415},
   {'Construction': 6.583333e-05},
   {'Consumer Electronics': 0.00040891767},
   {'Consumer Goods': 0.00018912554},
   {'Consumer Services': 2.9712915e-05},
   {'Cosmetics': 6.186962e-05},
   {'Dairy': 0.0},
   {'Defense & Space': 0.0064222515},
   {'Design': 0.00017467141},
   {'E-Learning': 7.4505806e-07},
   {'Education Management': 4.541874e-05},
   {'Electrical/Electronic Manufacturing': 0.0064535737},
   {'Entertainment': 2.8640032e-05},
   {'Environmental Services': 0.00027146935},
   {'Events Services': 1.1831522e-05},
   {'Executive Office': 2.503395e-06},
   {'Facilities Services': 0.00035235286},
   {'Farming': 9.23872e-07},
   {'Financial Services': 4.887581e-06},
   {'Fine Art': 1.3709068e-06},
   {'Fishery': 2.0861626e-07},
   {'Food & Beverages': 1.886487e-05},
   {'Food Production': 2.0861626e-05},
   {'Fund-Raising': 5.2154064e-06},
   {'Furniture': 4.1037798e-05},
   {'Gambling & Casinos': 1.4901161e-07},
   {'Glass, Ceramics & Concrete': 5.8948994e-05},
   {'Government Administration': 5.605817e-05},
   {'Government Relations': 2.1755695e-06},
   {'Graphic Design': 2.9802322e-08},
   {'Health, Wellness and Fitness': 0.0006379187},
   {'Higher Education': 0.00028717518},
   {'Hospital & Health Care': 0.07856926},
   {'Hospitality': 7.349253e-05},
   {'Human Resources': 5.5789948e-05},
   {'Import and Export': 1.1622906e-06},
   {'Individual & Family Services': 6.556511e-07},
   {'Industrial Automation': 0.00062918663},
   {'Information Services': 2.1278858e-05},
   {'Information Technology and Services': 0.0008093715},
   {'Insurance': 2.2351742e-06},
   {'International Affairs': 2.682209e-07},
   {'International Trade and Development': 6.854534e-07},
   {'Internet': 1.5974045e-05},
   {'Investment Banking': 1.1920929e-07},
   {'Investment Management': 4.440546e-06},
   {'Judiciary': 0.0},
   {'Law Enforcement': 4.7385693e-06},
   {'Law Practice': 7.1525574e-06},
   {'Legal Services': 3.2782555e-07},
   {'Legislative Office': 4.4703484e-07},
   {'Leisure, Travel & Tourism': 8.702278e-06},
   {'Libraries': 0.0},
   {'Logistics and Supply Chain': 0.0006325245},
   {'Luxury Goods & Jewelry': 0.0},
   {'Machinery': 0.001326263},
   {'Management Consulting': 0.0019137561},
   {'Maritime': 0.0006894171},
   {'Market Research': 3.963709e-06},
   {'Marketing and Advertising': 8.4877014e-05},
   {'Mechanical or Industrial Engineering': 0.004047543},
   {'Media Production': 4.172325e-07},
   {'Medical Devices': 0.06298205},
   {'Medical Practice': 0.00040200353},
   {'Mental Health Care': 9.059906e-06},
   {'Military': 0.0003131926},
   {'Mining & Metals': 2.7805567e-05},
   {'Motion Pictures and Film': 5.662441e-07},
   {'Museums and Institutions': 4.1127205e-06},
   {'Music': 2.115965e-06},
   {'Nanotechnology': 0.0020281076},
   {'Newspapers': 8.940697e-08},
   {'Non-Profit Organization Management': 2.2560358e-05},
   {'Oil & Energy': 0.00011694431},
   {'Online Media': 1.758337e-06},
   {'Outsourcing/Offshoring': 5.632639e-06},
   {'Package/Freight Delivery': 0.0},
   {'Packaging and Containers': 7.1287155e-05},
   {'Paper & Forest Products': 8.940697e-08},
   {'Performing Arts': 1.859665e-05},
   {'Personal Services': 0.0},
   {'Pharmaceuticals': 0.0032604039},
   {'Philanthropy': 1.1622906e-06},
   {'Photography': 1.4901161e-07},
   {'Plastics': 2.9087067e-05},
   {'Political Organization': 9.864569e-06},
   {'Primary/Secondary Education': 4.172325e-07},
   {'Printing': 3.2782555e-05},
   {'Professional Training & Coaching': 8.2075596e-05},
   {'Program Development': 1.5199184e-06},
   {'Public Policy': 6.2584877e-07},
   {'Public Relations and Communications': 3.695488e-06},
   {'Public Safety': 3.9607286e-05},
   {'Publishing': 1.847744e-06},
   {'Railroad Manufacture': 0.0},
   {'Ranching': 4.4703484e-07},
   {'Real Estate': 9.536743e-07},
   {'Recreational Facilities and Services': 1.4901161e-07},
   {'Religious Institutions': 1.7881393e-07},
   {'Renewables & Environment': 1.1503696e-05},
   {'Research': 0.0029361248},
   {'Restaurants': 5.9604645e-08},
   {'Retail': 0.00057554245},
   {'Security and Investigations': 1.5705824e-05},
   {'Semiconductors': 0.8675323},
   {'Shipbuilding': 1.168251e-05},
   {'Sporting Goods': 1.0192394e-05},
   {'Sports': 8.016825e-06},
   {'Staffing and Recruiting': 0.00021097064},
   {'Supermarkets': 4.6789646e-06},
   {'Telecommunications': 0.0016988218},
   {'Textiles': 9.506941e-06},
   {'Think Tanks': 1.2814999e-06},
   {'Tobacco': 0.0},
   {'Translation and Localization': 5.6624413e-06},
   {'Transportation/Trucking/Railroad': 1.5258789e-05},
   {'Utilities': 1.7881393e-07},
   {'Venture Capital & Private Equity': 1.5497208e-06},
   {'Veterinary': 0.00013184547},
   {'Warehousing': 0.0001757443},
   {'Wholesale': 0.00035442604},
   {'Wine and Spirits': 3.9249304e-07},
   {'Wireless': 0.00034996684},
   {'Writing and Editing': 1.0294845e-06}]}]

>>> guess_industry('Micron')
'Semiconductors'

```